( cd opt/kde/share/doc/HTML/ja/okular ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/okular ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
( cd opt/kde/share/doc/HTML/ja/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kdesu ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
( cd opt/kde/share/doc/HTML/ja/knetwalk ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/knetwalk ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
( cd opt/kde/share/doc/HTML/ja/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kshisen ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
( cd opt/kde/share/doc/HTML/ja/ksquares ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/ksquares ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
( cd opt/kde/share/doc/HTML/ja/kollision ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kollision ; ln -sf /opt/kde/share/doc/HTML/ja//common common )
